@@ -90,8 +90,10 @@ class EmitSeries(object):
                 continue
 
             if series.identified_by not in ['ep', 'sequence']:
-                log.verbose('Can only emit ep or sequence based series. `%s` is identified_by %s' %
-                            (series.name, series.identified_by or 'auto'))
+                if not task.is_rerun:
+                    log.verbose('Can only emit ep or sequence based series. '
+                                '`%s` is identified_by %s' %
+                                (series.name, series.identified_by or 'auto'))
                 continue
 
             low_season = 0 if series.identified_by == 'ep' else -1
@@ -140,8 +142,10 @@ class EmitSeries(object):
                         if config.get('from_start') or config.get('backfill'):
                             entries.append(self.search_entry(series, season, 1, task))
                         else:
-                            log.verbose('Series `%s` has no history. Set begin option, or use CLI `series begin` '
-                                        'subcommand to set first episode to emit' % series.name)
+                            if not task.is_rerun:
+                                log.verbose('Series `%s` has no history. Set begin option, '
+                                            'or use CLI `series begin` '
+                                            'subcommand to set first episode to emit' % series.name)
                             break
 
                     if not config.get('backfill'):
@@ -150,6 +154,7 @@ class EmitSeries(object):
         return entries
 
     def on_search_complete(self, entry, task=None, identified_by=None, **kwargs):
+        """Decides whether we should look for next ep/season based on whether we found/accepted any episodes."""
         with Session() as session:
             series = session.query(Series).filter(Series.name == entry['series_name']).first()
             latest = get_latest_release(series)
@@ -160,6 +165,8 @@ class EmitSeries(object):
                        first())
             if entry.accepted or (episode and len(episode.releases) > 0):
                 self.try_next_season.pop(entry['series_name'], None)
+                log.debug('%s %s was accepted, rerunning to look for next ep.' %
+                          (entry['series_name'], entry['series_id']))
                 task.rerun()
             elif latest and latest.season == entry['series_season']:
                 if identified_by != 'ep':
@@ -167,6 +174,8 @@ class EmitSeries(object):
                     return
                 if entry['series_name'] not in self.try_next_season:
                     self.try_next_season[entry['series_name']] = True
+                    log.debug('%s %s not found, rerunning to look for next season' %
+                              (entry['series_name'], entry['series_id']))
                     task.rerun()
                 else:
                     # Don't try a second time
