@@ -17,6 +17,7 @@ class MetainfoQuality(object):
 
     schema = {'type': 'boolean'}
 
+    @plugin.priority(127)  # Run after other plugins that might fill quality (series)
     def on_task_metainfo(self, task, config):
         # check if disabled (value set to false)
         if config is False:
@@ -33,18 +34,9 @@ class MetainfoQuality(object):
             log.debug('Quality is already set to %s for %s, skipping quality detection.' %
                       (entry['quality'], entry['title']))
             return
-        quality = qualities.Quality()
-        for field_name in ['title', 'description']:
-            if field_name not in entry:
-                continue
-            quality = qualities.Quality(entry[field_name])
-            if quality:
-                # if we find a quality in this field, stop searching
-                break
-        entry['quality'] = quality
-        if quality:
-            log.trace('Found quality %s (%s) for %s from field %s' %
-                (entry['quality'], quality, entry['title'], field_name))
+        entry['quality'] = qualities.Quality(entry['title'])
+        if entry['quality']:
+            log.trace('Found quality %s for %s' % (entry['quality'], entry['title']))
 
 
 @event('plugin.register')
