@@ -13,7 +13,6 @@ log = logging.getLogger('serienjunkies')
 LANGUAGE = ['de', 'en', 'both']
 HOSTER = ['ul', 'cz', 'so']
 
-
 class UrlRewriteSerienjunkies(object):
 
     """
@@ -88,10 +87,12 @@ class UrlRewriteSerienjunkies(object):
         # filter language
         if config['language'] in ['de', 'both']:
             if not re.search('german|deutsch', episode_lang, flags=re.IGNORECASE):
-                raise UrlRewritingError('Language doesn\'t match')
-        if config['language'] in ['en', 'both']:
+                log.verbose('Language doesn\'t match')
+                entry.reject('Language doesn\'t match')
+        elif config['language'] in ['en', 'both']:
             if not re.search('englisc?h', episode_lang, flags=re.IGNORECASE):
-                raise UrlRewritingError('Language doesn\'t match')
+                log.verbose('Language doesn\'t match')
+                entry.reject('Language doesn\'t match')
 
         # find download links
         links = episode.find_all('a')
@@ -108,9 +109,10 @@ class UrlRewriteSerienjunkies(object):
             if re.match(pattern, url):
                 return url
             else:
-                log.debug('Hoster does not match')
+                log.verbose('Hoster doesn\'t match')
                 continue
-
+        
+        raise UrlRewritingError('URL-Rewriting failed, enable verbose logging for details.')
 
 @event('plugin.register')
 def register_plugin():
